@@ -11,6 +11,11 @@ def parse_date(date):
         return date
     return (date or datetime.datetime.now()).strftime('%m-%d-%Y')
 
+def parse_ymd_date(date):
+    if type(date) == str:
+        date = arrow.get(date)
+    return (date or datetime.datetime.now()).strftime('%Y-%m-%d')
+
 def parsed_date_to_arrow(date):
     return arrow.get(datetime.datetime.strptime(date, '%m-%d-%Y'))
 
@@ -117,17 +122,17 @@ def split_days_range(start_a, end_a, days: int = 5) -> List[Tuple[str, str]]:
         if (cur - cur_s).days >= days-1:
             ranges.append((cur_s, cur))
             cur_s = cur + datetime.timedelta(days=1)
-        
+
         cur += datetime.timedelta(days=1)
     if len(ranges) > 0 and (end - ranges[-1][-1]).days > 0:
         ranges.append((cur_s, end))
-    
+
     return ranges
 
 class ApiException(Exception):
     def __init__(self, status_code, text, *args, **kwargs):
         self.status_code = status_code
-        super().__init__('%s (HTTP %s)' % (text, status_code), *args, **kwargs)
+        super().__init__('%s%s' % (text, ' (HTTP %s)' % status_code if status_code else ''), *args, **kwargs)
 
 class ApiLoginException(ApiException):
     pass
\ No newline at end of file
