@@ -5,7 +5,7 @@ import logging
 
 from bs4 import BeautifulSoup
 
-from ..util import timeago
+from ..util import timeago, cap_length
 from .common import parse_date, base_headers, base_session, ApiException, ApiLoginException
 
 logger = logging.getLogger(__name__)
@@ -14,7 +14,7 @@ class ControlIQApi:
     BASE_URL = 'https://tdcservices.tandemdiabetes.com/'
     LOGIN_URL = 'https://tconnect.tandemdiabetes.com/login.aspx?ReturnUrl=%2f'
 
-    LAST_CONFIRMED_SOFTWARE_VERSION = 't:connect 7.14.0.1'
+    LAST_CONFIRMED_SOFTWARE_VERSION = 't:connect 7.17.2.3'
 
     userGuid = None
     accessToken = None
@@ -34,18 +34,38 @@ class ControlIQApi:
             data = self._build_login_data(email, password, soup)
 
             req = s.post(self.LOGIN_URL, data=data, headers={'Referer': self.LOGIN_URL, **base_headers()}, allow_redirects=False)
+            # HTTP 200 is reported when credentials are incorrect
+            if req.status_code == 200:
+                login_error = self._find_login_error(req.text)
+                if not login_error:
+                    login_error = 'Check your login credentials.'
+                raise ApiLoginException(None, 'Error logging in to t:connect: %s' % login_error)
+
             if req.status_code != 302:
-                raise ApiLoginException(req.status_code, 'Error logging in to t:connect. Check your login credentials.')
+                raise ApiLoginException(req.status_code, 'Error logging in to t:connect')
 
 
             fwd = s.post(urllib.parse.urljoin(self.LOGIN_URL, req.headers['Location']), cookies=req.cookies, headers=base_headers())
             if fwd.status_code != 200:
+                logger.warn("Received non-HTTP 200: %s" % req.text)
                 raise ApiException(fwd.status_code, 'Error retrieving t:connect login cookies.')
 
             self.userGuid = req.cookies['UserGUID']
-            self.accessToken = req.cookies['accessToken']
-            self.accessTokenExpiresAt = req.cookies['accessTokenExpiresAt']
-            logger.info("Logged in to ControlIQApi successfully (expiration: %s, %s)" % (self.accessTokenExpiresAt, timeago(self.accessTokenExpiresAt)))
+            if 'accessToken' in req.cookies and 'accessTokenExpiresAt' in req.cookies:
+                self.accessToken = req.cookies['accessToken']
+                self.accessTokenExpiresAt = req.cookies['accessTokenExpiresAt']
+                logger.info("Logged in to ControlIQApi successfully via accessToken cookie (expiration: %s, %s)" % (self.accessTokenExpiresAt, timeago(self.accessTokenExpiresAt)))
+            else:
+                logger.info("No accessToken cookie found when logging in to ControlIQApi. Triggering AndroidApi auth")
+
+                from .android import AndroidApi
+                android = AndroidApi(email, password)
+                self.accessToken = android.accessToken
+                self.accessTokenExpiresAt = android.accessTokenExpiresAt
+
+                logger.info("Logged in to AndroidApi successfully via accessToken param (expiration: %s, %s)" % (self.accessTokenExpiresAt, timeago(self.accessTokenExpiresAt)))
+
+
             self.loginSession = s
             return True
 
@@ -66,6 +86,13 @@ class ControlIQApi:
                     contents = "%s[SNIP]%s" % (contents[:500], contents[-500:])
             logger.info("BeautifulSoup parsed contents: %s" % contents)
             pass
+        if not soup.select_one("#__VIEWSTATE"):
+            enc_contents = str(soup.encode_contents())
+            if "Web Page Blocked!" in enc_contents or "Attack ID:" in enc_contents:
+                logger.warn("Being ratelimited/blocked by web application firewall. Sleeping for 30 minutes before retrying.")
+                logger.info("BeautifulSoup parsed contents: %s" % enc_contents)
+                time.sleep(1800)
+                exit(1)
         return {
             "__LASTFOCUS": "",
             "__EVENTTARGET": "ctl00$ContentBody$LoginControl$linkLogin",
@@ -79,7 +106,18 @@ class ControlIQApi:
             "txtLoginPassword_ClientState": '{"enabled":true,"emptyMessage":"","validationText":"%s","valueAsString":"%s","lastSetTextBoxValue":"%s"}' % (password, password, password)
         }
 
+    def _find_login_error(self, text):
+        try:
+            soup = BeautifulSoup(text, features='lxml')
+            notice_error = soup.select_one(".notice_error").text.strip()
+            return notice_error
+        except Exception:
+            return None
+
     def needs_relogin(self):
+        if not self.accessTokenExpiresAt:
+            return False
+
         diff = (arrow.get(self.accessTokenExpiresAt) - arrow.get())
         return (diff.seconds <= 5 * 60)
 
