@@ -9,11 +9,13 @@ CGM = "CGM"
 PUMP_EVENTS = "PUMP_EVENTS"
 PUMP_EVENTS_BASAL_SUSPENSION = "PUMP_EVENTS_BASAL_SUSPENSION"
 PROFILES = "PROFILES"
+CGM_ALERTS = "CGM_ALERTS"
 
 DEFAULT_FEATURES = [
     BASAL,
     BOLUS,
-    PUMP_EVENTS
+    PUMP_EVENTS,
+    PROFILES
 ]
 
 ALL_FEATURES = [
@@ -22,13 +24,14 @@ ALL_FEATURES = [
     IOB,
     PUMP_EVENTS,
     PUMP_EVENTS_BASAL_SUSPENSION,
-    PROFILES
+    PROFILES,
+    CGM,
+    CGM_ALERTS,
 ]
 
 
 # These modes are not yet ready for wide use.
 if ENABLE_TESTING_MODES:
     ALL_FEATURES += [
-        BOLUS_BG,
-        CGM
+        BOLUS_BG
     ]
\ No newline at end of file
