@@ -30,10 +30,11 @@ def time_range(field_name, start_time, end_time, t_to_space=False):
 
 logger = logging.getLogger(__name__)
 class NightscoutApi:
-	def __init__(self, url, secret, skip_verify=False):
+	def __init__(self, url, secret, skip_verify=False, ignore_conn_errors=False):
 		self.url = url
 		self.secret = secret
 		self.verify = False if skip_verify else None
+		self.ignore_conn_errors = ignore_conn_errors
 
 
 	def upload_entry(self, ns_format, entity='treatments'):
@@ -76,23 +77,28 @@ class NightscoutApi:
 			if j and len(j) > 0:
 				return j[0]
 			return None
-		
-		ret = None
 		try:
-			ret = internal(False)
-		except ApiException as e:
-			logger.warning("last_uploaded_entry with no t_to_space: %s", e)
 			ret = None
-		if ret is None and (time_start or time_end):
 			try:
-				ret = internal(True)
+				ret = internal(False)
 			except ApiException as e:
-				logger.warning("last_uploaded_entry with t_to_space: %s", e)
+				#logger.warning("last_uploaded_entry with no t_to_space: %s", e)
 				ret = None
-			if ret is not None:
-				logger.warning("last_uploaded_entry with eventType=%s time_start=%s time_end=%s only returned data when timestamps contained a space" % (eventType, time_start, time_end))
-		return ret
-	
+			if ret is None and (time_start or time_end):
+				try:
+					ret = internal(True)
+				except ApiException as e:
+					#logger.warning("last_uploaded_entry with t_to_space: %s", e)
+					ret = None
+				if ret is not None:
+					logger.warning("last_uploaded_entry with eventType=%s time_start=%s time_end=%s only returned data when timestamps contained a space" % (eventType, time_start, time_end))
+			return ret
+		except requests.exceptions.ConnectionError as e:
+			if self.ignore_conn_errors:
+				logger.warn('Ignoring ConnectionError because ignore_conn_errors=true', e)
+			else:
+				raise e
+
 	def last_uploaded_bg_entry(self, time_start=None, time_end=None):
 		def internal(t_to_space):
 			dateFilter = time_range('dateString', time_start, time_end, t_to_space=t_to_space)
@@ -106,13 +112,20 @@ class NightscoutApi:
 			if j and len(j) > 0:
 				return j[0]
 			return None
-		
-		ret = internal(False)
-		if ret is None and (time_start or time_end):
-			ret = internal(True)
-			if ret is not None:
-				logger.warning("last_uploaded_bg_entry with time_start=%s time_end=%s only returned data when timestamps contained a space" % (time_start, time_end))
-		return ret
+
+		try:
+			ret = internal(False)
+			if ret is None and (time_start or time_end):
+				ret = internal(True)
+				if ret is not None:
+					logger.warning("last_uploaded_bg_entry with time_start=%s time_end=%s only returned data when timestamps contained a space" % (time_start, time_end))
+
+			return ret
+		except requests.exceptions.ConnectionError as e:
+			if self.ignore_conn_errors:
+				logger.warn('Ignoring ConnectionError because ignore_conn_errors=true', e)
+			else:
+				raise e
 
 	def last_uploaded_activity(self, activityType, time_start=None, time_end=None):
 		def internal(t_to_space):
@@ -127,13 +140,19 @@ class NightscoutApi:
 			if j and len(j) > 0:
 				return j[0]
 			return None
-		
-		ret = internal(False)
-		if ret is None and (time_start or time_end):
-			ret = internal(True)
-			if ret is not None:
-				logger.warning("last_uploaded_activity with activityType=%s time_start=%s time_end=%s only returned data when timestamps contained a space" % (activityType, time_start, time_end))
-		return ret
+
+		try:
+			ret = internal(False)
+			if ret is None and (time_start or time_end):
+				ret = internal(True)
+				if ret is not None:
+					logger.warning("last_uploaded_activity with activityType=%s time_start=%s time_end=%s only returned data when timestamps contained a space" % (activityType, time_start, time_end))
+			return ret
+		except requests.exceptions.ConnectionError as e:
+			if self.ignore_conn_errors:
+				logger.warn('Ignoring ConnectionError because ignore_conn_errors=true', e)
+			else:
+				raise e
 
 	"""
 	Returns general status information about the Nightscout server.
@@ -145,7 +164,7 @@ class NightscoutApi:
 		if status.status_code != 200:
 			raise Exception('HTTP error status code (%d) from Nightscout: %s' % (status.status_code, status.text))
 		return status.json()
-	
+
 	"""
 	Returns information on the currently configured Nightscout profile data store
 	(contains all profiles in Nightscout under one mongo object).
